@@ -1,5 +1,5 @@
 from django.contrib import admin
-from polls.models import Choice, Poll, UserChoice
+from polls.models import Choice, Poll, UserChoice, AnonymousUserChoice
 
 
 class ChoiceInline(admin.StackedInline):
@@ -17,3 +17,8 @@ class UserChoiceAdmin(admin.ModelAdmin):
     pass
 
 admin.site.register(UserChoice, UserChoiceAdmin)
+    
+class AnonymousUserChoiceAdmin(admin.ModelAdmin):
+    pass
+
+admin.site.register(AnonymousUserChoice, AnonymousUserChoiceAdmin)
\ No newline at end of file
