@@ -6,6 +6,8 @@ from django import template
 from polls.forms import PollVoteForm
 from polls.methods import get_poll_form, get_poll_vote_form
 
+from coffee.mixins import FormMixin
+
 register = template.Library()
 
 COLORS = [
@@ -32,7 +34,15 @@ COLORS = [
 @register.inclusion_tag('polls/poll/partial/poll.html')
 def poll_form(instance, request):
     form, formset = get_poll_form(instance, request)
-
+    
+    coffee = FormMixin()
+    
+    placeholders = {
+        'question': 'Question'
+    }
+    
+    coffee.construct_widgets(form.fields, placeholders, must_delete=False)
+    
     return {'form': form, 'formset': formset}
 
 
